@@ -111,7 +111,7 @@ class GmeClient(AbstractClient):
 
 
     def ModifyAppStatus(self, request):
-        """This API is used to change the status of an application's master switch.
+        """This API is used to change the status of an application's primary switch.
 
         :param request: Request instance for ModifyAppStatus.
         :type request: :class:`tencentcloud.gme.v20180711.models.ModifyAppStatusRequest`
@@ -185,7 +185,7 @@ class GmeClient(AbstractClient):
         <p>ad: advertising</p>
         <p>terrorism: terrorism</p>
         <p>contraband: prohibited</p>
-        <p>customized: custom keyword library. This feature is only available to whitelisted users. To try it out, please <a href="https://cloud.tencent.com/apply/p/8809fjcik56">contact us</a>.</p>
+        <p>customized: custom keyword library. This feature is only available to allowlisted users. To try it out, please <a href="https://cloud.tencent.com/apply/p/8809fjcik56">contact us</a>.</p>
         </td>
         </tr>
         </tbody>
